<?php

namespace Drupal\video_embed_twentythree\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Video Embed TwentyThree settings.
 */
class TwentyThreeSettngsForm extends ConfigFormBase {

  /**
   * The video_embed_twentythree configuration.
   *
   * @var array
   *
   * @see \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * Constructs a CropWidgetForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    parent::__construct($config_factory);
    $this->config = $this->config('video_embed_twentythree.settings');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static (
      $container->get('config.factory')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'video_embed_twentythree_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['video_embed_twentythree.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['video_domains'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Custom video domains'),
      '#description' => $this->t('Fill in the TwentyThree video domains allowed on this site. E.g. customer.domain.tld, domain.tld etc. One domain per line. Write the domains without http(s):// and trailing slash.'),
      '#default_value' => $this->config->get('video_domains'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    // Clean up string with domains.
    $domains = $form_state->getValue('video_domains');
    $domains = explode("\n", $domains);
    $domains = array_map('trim', $domains);
    $domains = array_filter($domains);
    $domains = implode("\n", $domains);

    $this->config->set("video_domains", $domains);
    $this->config->save();
  }

}
